repositoryx

package
v0.0.0-...-6b1b9c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package repositoryx is a set of util functions to be used in repositories.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Order

type Order uint8

Order present sql order ACS or DESC.

const (
	OrderAsc  Order = iota // ASC
	OrderDesc              // DESC
)

Allowed ordering.

func (Order) ToString

func (o Order) ToString(field string) string

ToString converts Order to string for given field name.

Directories

Path Synopsis
Package pg utils for work with pg.
Package pg utils for work with pg.

Jump to